//  Коды доступа для аутентификации студентов.
//  Студент не имеет классической учетной записи,
//  а входит в программу по личному коду доступа,
//  который он может получить от учителя лично, по
//  по почте или сформировать по приглашению.
//

//////////////////////////////////////////////////////
// Карточка
//

// Документ с кодами доступа студентов.
//
import {DocumentStorageInterface} from "../common/storage.interface";

export interface CodeStorageInterface extends DocumentStorageInterface {
    room: string;
    group: string;
    value: number;
    email?: string;
    invite?: string;
    student?: string;
}

//////////////////////////////////////////////////////
// Обмен клиента и сервера
//

// Данные, которые необходимое отправить на сервер
// для аутентификации студента.
//
export interface CodeAuthRequestInterface {
    roomNumber: string;
    codeValue: string;
}

// Данные авторизации студента, которые возвращаются
// с сервера при удачной авторизации.
//
export interface CodeAuthResponseInterface {
    teacher: string;
    student: string;
}

// Проверяет валидность данных авторизации студента.
//
export function CodeAuthResponseDataValid(data: CodeAuthResponseInterface): boolean {
    return (
        data && typeof data === "object" &&
        "teacher" in data && !!data.teacher &&
        "student" in data && !!data.student
    );
}

// Данные ошибки авторизации студента, если авторизация
// не удалась.
//
export interface CodeAuthErrorsInterface {
    code: number;
    message: CodeAuthErrors;
}

// Проверяет валидность данных ошибки аутентификации студента.
//
export function CodeAuthErrorsDataValid(data: CodeAuthErrorsInterface): boolean {
    return (
        data && typeof data === "object" &&
        "code" in data && data.code === 400 &&
        "message" in data && !!codeAuthErrors[data.message]);
}

// Коды ошибок аутентификации.
//
export type CodeAuthErrors = "BAD_REQUEST" | "INVALID_AUTH" | "UNKNOWN" | "EMPTY" | string;

export const codeAuthErrors = {
    BAD_REQUEST: "BAD_REQUEST" as CodeAuthErrors,
    INVALID_AUTH: "INVALID_AUTH" as CodeAuthErrors,
    UNKNOWN: "UNKNOWN" as CodeAuthErrors,
    EMPTY: "EMPTY" as CodeAuthErrors
};
