// Одним из способов получение кода доступа для студента
// является активация приглашения. Приглашение может быть
// трех типов:

// 1. Ручное. Создается приглашение и коды доступа к нему.
// Коды доступа раздаются студентам вручную. В карточке
// приглашения хранятся готовые коды доступа.

// 2. Почта. Создается приглашение и коды доступа к нему.
// Коды доступа рассылаются на адрес электронной почты.

// 3. Общее. Создается общее приглашение.
// Общее приглашение активируется студентом. При активации
// вводится его имя и адрес электронной почты, на который высылается
// код доступа или выполняется вход автоматически с одноразовым кодом.

import {DocumentStorageInterface} from "../common/storage.interface";

export type InviteTypes = "MANUAL" | "MAIL" | "COMMON";

export const inviteTypes = {
    MANUAL: "MANUAL" as InviteTypes,
    MAIL: "MAIL" as InviteTypes,
    COMMON: "COMMON" as InviteTypes,
};

//////////////////////////////////////////////////////
// Карточка
//

// Документ с приглашением для самостоятельной регистрации студентом
//
export interface InviteStorageInterface extends DocumentStorageInterface {
    room: string;
    group: string;
    type: InviteTypes;
    date: Date;
    settings?: ManualSettingsInviteInterface | MailSettingsInviteInterface | CommonSettingsInviteInterface;
}

// Настройки ручного приглашения
//
export interface ManualSettingsInviteInterface {
    numberCodes: number;
}

// Настройки ручного приглашения
//
export interface MailSettingsInviteInterface {
    numberInvites: number;
}

// Настройки общего приглашения
//
export interface CommonSettingsInviteInterface {
    commonCode: number;
}

//////////////////////////////////////////////////////
// Представление в списках
//

// Элемент списка приглашения в карточке группы
//
export interface InviteListItemInterface {
    type: InviteTypes;
}