import {DocumentStorageInterface} from "../common/storage.interface";
import {TaskListItemInterface} from "./task.interface";
import {GroupListItemInterface} from "./group.interface";
import {WorkListItemInterface} from "./work.interface";

//////////////////////////////////////////////////////
// Карточка
//

// Документ комнаты в БД
//
export interface RoomStorageInterface extends DocumentStorageInterface {
    name: string;
    tasks?: RoomTasks;
    groups?: RoomGroups;
    works?: WorkTasks;
}

// Группы студентов комнаты
//
export interface RoomGroups {
    [uuid: string]: GroupListItemInterface;
}

// Задания комнаты
//
export interface RoomTasks {
    [uuid: string]: TaskListItemInterface;
}

// Работы в комнате
//
export interface WorkTasks {
    [uuid: string]: WorkListItemInterface;
}

//////////////////////////////////////////////////////
// Представление в списках
//

// Элемент списка комнат в кабинете учителя
//
export interface RoomListItemInterface {
    name: string;
}

//////////////////////////////////////////////////////
// Документ комнаты в общем глобальном списке
//

export interface RoomGlobalDocInterface {
    teacher: string;
    uuid: string;
}

//////////////////////////////////////////////////////
// Создание комнаты в БД
//

// Данные, которые передаются на сервер для создания комнаты
//
export interface RoomAddReqInterface {
    newDoc: RoomStorageInterface;
    newListElement: RoomListItemInterface;
}

// Ошибки, которые могут придти с сервера при создании комнаты
//
export type AddRoomCodeErrors = "invalid-argument" | "already-exists";
export const addRoomCodeErrors = {
    "invalid-argument": "invalid-argument" as AddRoomCodeErrors,
    "already-exists": "already-exists" as AddRoomCodeErrors,
};

// Ответ с сервере об ошибке создания комнаты.
//
export interface RoomAddResErrorInterface {
    code: AddRoomCodeErrors | AddRoomCodeValidate;
}

// Ошибки, которые обрабатываются при валидации формы создания комнаты
//
export type AddRoomCodeValidate = "too-short" | "too-long" | "empty";
export const addRoomCodeValidate = {
    "too-short": "too-short" as AddRoomCodeValidate,
    "too-long": "too-long" as AddRoomCodeValidate,
    "empty": "empty" as AddRoomCodeValidate,
};

