
// Проверяет валидность данных запроса.
//
import {addRoomCodeErrors, addRoomCodeValidate, RoomAddReqInterface, RoomAddResErrorInterface} from "./room.interface";

export const roomNameMaxLength = 100;
export const roomNameMinLength = 4;

export function roomAddReqDataValid(data: RoomAddReqInterface): boolean {
    return (
        data
        && typeof data === "object"
        && Object.keys(data).length === 2
        && "newDoc" in data
        && !!data.newDoc
        && "name" in data.newDoc
        && data.newDoc.name.length <= roomNameMaxLength
        && data.newDoc.name.length >= roomNameMinLength
        && "newListElement" in data
        && !!data.newListElement
    );
}

// Проверяет валидность данных сервера с ошибкой создания комнаты.
//
export function roomAddResErrorDataValid(data: RoomAddResErrorInterface): boolean {
    return (
        data
        && typeof data === "object"
        && "code" in data
        && (data.code === addRoomCodeErrors["invalid-argument"]
            || data.code === addRoomCodeErrors["already-exists"]
            || data.code === addRoomCodeValidate["too-short"]
            || data.code === addRoomCodeValidate["too-long"]
            || data.code === addRoomCodeValidate["empty"])
    );
}
